summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/codegenpolicyext.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/codegenpolicyext.h')
-rw-r--r--umbrello/umbrello/codegenerators/codegenpolicyext.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/codegenerators/codegenpolicyext.h b/umbrello/umbrello/codegenerators/codegenpolicyext.h
index 29e358a1..b95cfdac 100644
--- a/umbrello/umbrello/codegenerators/codegenpolicyext.h
+++ b/umbrello/umbrello/codegenerators/codegenpolicyext.h
@@ -15,7 +15,7 @@
#include <tqobject.h>
class TQWidget;
-class KConfig;
+class TDEConfig;
class CodeGenerationPolicyPage;
/**
@@ -39,14 +39,14 @@ public:
virtual CodeGenerationPolicyPage * createPage(TQWidget *parent = 0, const char *name = 0) = 0;
/**
* set the defaults from a config file for this code generator from the passed KConfig pointer.
*/
- virtual void setDefaults(KConfig * config, bool emitUpdateSignal = true) = 0;
+ virtual void setDefaults(TDEConfig * config, bool emitUpdateSignal = true) = 0;
/**
* write Default params to passed KConfig pointer.
*/
- virtual void writeConfig (KConfig * config) = 0;
+ virtual void writeConfig (TDEConfig * config) = 0;
};
#endif
@@ -39,14 +39,14 @@ public:
virtual CodeGenerationPolicyPage * createPage(TQWidget *parent = 0, const char *name = 0) = 0;
/**
- * set the defaults from a config file for this code generator from the passed KConfig pointer.
+ * set the defaults from a config file for this code generator from the passed TDEConfig pointer.
*/
@@ -39,14 +39,14 @@ public:
/**
- * write Default params to passed KConfig pointer.
+ * write Default params to passed TDEConfig pointer.
*/